@@ -1,10 +1,10 @@
 import time
-from tzlocal import get_localzone
 from datetime import datetime, timedelta
 from ..models import MessageListResult
 from ..models import Message
 from ..models import MailosaurException
 
+
 class MessagesOperations(object):
     """MessagesOperations operations.
     """
@@ -12,7 +12,6 @@ class MessagesOperations(object):
     def __init__(self, session, base_url, handle_http_error):
         self.session = session
         self.base_url = base_url
-        self.timezone = get_localzone()
         self.handle_http_error = handle_http_error
 
     def get(self, server, criteria, timeout=10000, received_after=(datetime.today() - timedelta(hours=1))):
@@ -36,9 +35,11 @@ class MessagesOperations(object):
         """
         # Defaults timeout to 10s, receivedAfter to 1h
         if len(server) != 8:
-            raise MailosaurException("Must provide a valid Server ID.", "invalid_request")
+            raise MailosaurException(
+                "Must provide a valid Server ID.", "invalid_request")
 
-        result = self.search(server, criteria, 0, 1, timeout, received_after, True)
+        result = self.search(server, criteria, 0, 1,
+                             timeout, received_after, True)
         return self.get_by_id(result.items[0].id)
 
     def get_by_id(self, id):
@@ -56,7 +57,7 @@ class MessagesOperations(object):
         """
         url = "%sapi/messages/%s" % (self.base_url, id)
         response = self.session.get(url)
-        
+
         if response.status_code not in [200]:
             self.handle_http_error(response)
             return
@@ -80,7 +81,7 @@ class MessagesOperations(object):
         """
         url = "%sapi/messages/%s" % (self.base_url, id)
         response = self.session.delete(url)
-        
+
         if response.status_code not in [204]:
             self.handle_http_error(response)
             return
@@ -110,13 +111,12 @@ class MessagesOperations(object):
         url = "%sapi/messages" % (self.base_url)
 
         if received_after is not None:
-            if received_after.tzinfo is None or received_after.tzinfo.utcoffset(received_after) is None:
-                received_after = self.timezone.localize(received_after)
-            received_after = received_after.isoformat()
+            received_after = received_after.astimezone().replace(microsecond=0).isoformat()
 
-        params = {'server': server, 'page': page, 'itemsPerPage': items_per_page, 'receivedAfter': received_after}
+        params = {'server': server, 'page': page,
+                  'itemsPerPage': items_per_page, 'receivedAfter': received_after}
         response = self.session.get(url, params=params)
-        
+
         if response.status_code not in [200]:
             self.handle_http_error(response)
             return
@@ -142,7 +142,7 @@ class MessagesOperations(object):
         url = "%sapi/messages" % (self.base_url)
         params = {'server': server}
         response = self.session.delete(url, params=params)
-        
+
         if response.status_code not in [204]:
             self.handle_http_error(response)
             return
@@ -179,42 +179,125 @@ class MessagesOperations(object):
         url = "%sapi/messages/search" % (self.base_url)
 
         if received_after is not None:
-            if received_after.tzinfo is None or received_after.tzinfo.utcoffset(received_after) is None:
-                received_after = self.timezone.localize(received_after)
-            received_after = received_after.isoformat()
+            received_after = received_after.astimezone().replace(microsecond=0).isoformat()
 
-        params = {'server': server, 'page': page, 'itemsPerPage': items_per_page, 'receivedAfter': received_after}
+        params = {'server': server, 'page': page,
+                  'itemsPerPage': items_per_page, 'receivedAfter': received_after}
 
         poll_count = 0
         start_time = datetime.today()
 
         while True:
-            response = self.session.post(url, params=params, json=criteria.toJSON())
+            response = self.session.post(
+                url, params=params, json=criteria.to_json())
 
             if response.status_code not in [200]:
                 self.handle_http_error(response)
                 return
-            
+
             data = response.json()
 
             result = MessageListResult(data)
 
             if timeout is None or timeout == 0 or len(result.items) != 0:
                 return result
-            
+
             # List conversion necessary for Python 3 compatibility
             # https://stackoverflow.com/questions/36982858/object-of-type-map-has-no-len-in-python-3
-            delay_pattern = list(map(int, (response.headers.get('x-ms-delay') or '1000').split(',')))
+            delay_pattern = list(
+                map(int, (response.headers.get('x-ms-delay') or '1000').split(',')))
+
+            delay = delay_pattern[len(
+                delay_pattern) - 1] if poll_count >= len(delay_pattern) else delay_pattern[poll_count]
 
-            delay = delay_pattern[len(delay_pattern) - 1] if poll_count >= len(delay_pattern) else delay_pattern[poll_count]
-            
             poll_count += 1
 
-            ## Stop if timeout will be exceeded
+            # Stop if timeout will be exceeded
             if ((1000 * (datetime.today() - start_time).total_seconds()) + delay) > timeout:
                 if not error_on_timeout:
                     return result
                 else:
-                    raise MailosaurException("No matching messages found in time. By default, only messages received in the last hour are checked (use receivedAfter to override this).", "search_timeout")
+                    raise MailosaurException(
+                        "No matching messages found in time. By default, only messages received in the last hour are checked (use receivedAfter to override this).", "search_timeout")
 
-            time.sleep(delay / 1000)
\ No newline at end of file
+            time.sleep(delay / 1000)
+
+    def create(self, server, options):
+        """Create a message.
+
+        Creates a new message that can be sent to a verified email address. This is
+        useful in scenarios where you want an email to trigger a workflow in your
+        product
+
+        :param server: The identifier of the server to create the message in.
+        :type server: str
+        :param options: The options with which to create the message.
+        :type options: ~mailosaur.models.MessageCreateOptions
+        :return: None
+        :rtype: None
+        :raises:
+         :class:`MailosaurException<mailosaur.models.MailosaurException>`
+        """
+        url = "%sapi/messages" % (self.base_url)
+        params = {'server': server}
+        response = self.session.post(
+            url, params=params, json=options.to_json())
+
+        if response.status_code not in [200]:
+            self.handle_http_error(response)
+            return
+
+        data = response.json()
+
+        return Message(data)
+
+    def forward(self, id, options):
+        """Forward an email.
+
+        Forwards the specified email to a verified email address.
+
+        :param id: The identifier of the email to forward.
+        :type id: str
+        :param options: The options with which to forward the email.
+        :type options: ~mailosaur.models.MessageForwardOptions
+        :return: None
+        :rtype: None
+        :raises:
+         :class:`MailosaurException<mailosaur.models.MailosaurException>`
+        """
+        url = "%sapi/messages/%s/forward" % (self.base_url, id)
+        response = self.session.post(url, json=options.to_json())
+
+        if response.status_code not in [200]:
+            self.handle_http_error(response)
+            return
+
+        data = response.json()
+
+        return Message(data)
+
+    def reply(self, id, options):
+        """Reply to an email.
+
+        Sends a reply to the specified email. This is useful for when simulating a user
+        replying to one of your emails.
+
+        :param id: The identifier of the email to reply to.
+        :type id: str
+        :param options: The options with which to reply to the email.
+        :type options: ~mailosaur.models.MessageReplyOptions
+        :return: None
+        :rtype: None
+        :raises:
+         :class:`MailosaurException<mailosaur.models.MailosaurException>`
+        """
+        url = "%sapi/messages/%s/reply" % (self.base_url, id)
+        response = self.session.post(url, json=options.to_json())
+
+        if response.status_code not in [200]:
+            self.handle_http_error(response)
+            return
+
+        data = response.json()
+
+        return Message(data)
